@@ -27,9 +27,10 @@
 #include <QSortFilterProxyModel>
 
 #include <KConfigGroup>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
 #include <kwidgetsaddons_version.h>
 
 #include "iwfilelistmodel.h"
@@ -205,7 +206,9 @@ void FileView::showContextMenu(const QPoint &p)
 
 void FileView::open()
 {
-    new KRun(QUrl(preview_path), nullptr, true);
+    auto job = new KIO::OpenUrlJob(QUrl(preview_path), nullptr);
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+    job->start();
 }
 
 void FileView::changePriority(bt::Priority newpriority)
@@ -252,20 +255,7 @@ void FileView::deleteFiles()
                         "You will lose all data in these files, are you sure you want to do this?",
                         n);
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-    if (KMessageBox::warningTwoActions(nullptr,
-#else
-    if (KMessageBox::warningYesNo(nullptr,
-#endif
-                                       msg,
-                                       QString(),
-                                       KStandardGuiItem::del(),
-                                       KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-        == KMessageBox::PrimaryAction)
-#else
-        == KMessageBox::Yes)
-#endif
+    if (KMessageBox::warningTwoActions(nullptr, msg, QString(), KStandardGuiItem::del(), KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction)
         changePriority(EXCLUDED);
 }
 
@@ -340,13 +330,19 @@ void FileView::onDoubleClicked(const QModelIndex &index)
         bt::TorrentFileInterface *file = model->indexToFile(proxy_model->mapToSource(index));
         if (!file) {
             // directory
-            new KRun(QUrl(curr_tc->getDataDir() + model->dirPath(proxy_model->mapToSource(index))), nullptr, true);
+            auto job = new KIO::OpenUrlJob(QUrl(curr_tc->getDataDir() + model->dirPath(proxy_model->mapToSource(index))), nullptr);
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+            job->start();
         } else {
             // file
-            new KRun(QUrl(file->getPathOnDisk()), nullptr, true);
+            auto job = new KIO::OpenUrlJob(QUrl(file->getPathOnDisk()), nullptr);
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+            job->start();
         }
     } else {
-        new KRun(QUrl(curr_tc->getStats().output_path), nullptr, true);
+        auto job = new KIO::OpenUrlJob(QUrl(curr_tc->getStats().output_path), nullptr);
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+        job->start();
     }
 }
 
