@@ -72,9 +72,9 @@ void KGetSortFilterProxyModel::setShowWebContent(bool show)
     invalidateFilter();
 }
 
-void KGetSortFilterProxyModel::setShowWebContent(int show)
+void KGetSortFilterProxyModel::setShowWebContent(Qt::CheckState show)
 {
-    m_showWebContent = show;
+    m_showWebContent = show == Qt::Checked;
     invalidateFilter();
 }
 
@@ -128,7 +128,7 @@ bool KGetSortFilterProxyModel::acceptText(const QString &text) const
     // look if the text-filter matches
     const auto re = filterRegularExpression();
     const auto match = re.match(text);
-    bool accept = (match.hasMatch() != -1) ? true : false;
+    bool accept = match.hasMatch() ? true : false;
     if ((m_filterMode == DoesNotContain) && !re.pattern().isEmpty()) {
         accept = !accept;
     }
